Package 'GenomeNexus'

Title: Expose the GenomeNexus API as an R package
Description: This package provides an R interface to the GenomeNexus API. GenomeNexus is a web application that annotates cancer variants with information from multiple databases. The GenomeNexus API provides programmatic access to the data and annotations available in the GenomeNexus web application.
Authors: Marcel Ramos [aut, cre] (ORCID: <https://orcid.org/0000-0002-3242-0582>)
Maintainer: Marcel Ramos <[email protected]>
License: Artistic-2.0
Version: 0.0.0.9000
Built: 2026-06-03 06:42:34 UTC
Source: https://github.com/LiNk-NY/GenomeNexus

Help Index